/*
 * TkResolver++ - Psychokinesis testing software
 *
 * Copyright (C) 2004, 2005, 2006, 2007, 2008, 2009 Robert Ham <rah@bash.sh>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include "libtkcommon/tkintl.h"
#include "libtkdb/exception.h"

using namespace Tk::Db;

UnknownType:: UnknownType(const Tk::String &type_name, const Tk::String &domain)
  : std::logic_error(std::string(_("Unknown "))
		     + static_cast<std::string>(Tk::String((domain.length() > 0) ? (domain + Tk::String(" ")) : Tk::String("")))
		     + "type '"
		     + static_cast<std::string>(type_name) +
		     _("'")),
    _type_name(type_name)
{}

UnknownType:: ~UnknownType()
  throw ()
{
}

const Tk::String &
UnknownType:: get_type_name() const
{
  return _type_name;
}

PropertyNotSet:: PropertyNotSet(const Tk::String &domain, const Id &entity_id, const Tk::String &property_name)
  : std::runtime_error(std::string(_("Property `"))
		       + static_cast<std::string>(property_name)
		       + _("' not set for entity ")
		       + static_cast<std::string>(Tk::String(entity_id))
		       + _(" in domain `")
		       + static_cast<std::string>(domain)
		       + "'"
		       )
{}
