/* -*- c++ -*-
 * TkResolver++ - Psychokinesis testing software
 *
 * Copyright (C) 2004, 2005, 2006, 2007, 2009 Robert Ham <rah@bash.sh>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include "libtkdbui/domain_selector.h"

using namespace Tk::Db::Ui;

NoSelection:: NoSelection()
  : std::runtime_error("No selection")
{
}


DomainSelector:: DomainSelector(Db::Database *database,
				const Tk::String &domain,
				bool multiple_selection)
  : _database(database),
    _domain(domain),
    _store(Gtk::ListStore::create(_columns)),
    Gtk::TreeView()
{
  set_model(_store);
  
  _column.pack_start(_renderer);
  Glib::ustring udomain(static_cast<std::string>(domain));
  udomain.replace(0, 1, udomain.substr(0, 1).uppercase());
  _column.set_title(udomain);
  append_column(_column);
  _column.set_cell_data_func(_renderer, sigc::mem_fun(*this, &DomainSelector::cell_data) );
  
  if (multiple_selection)
    get_selection()->set_mode(Gtk::SELECTION_MULTIPLE);
  
  Tk::Db::Ids entity_ids( database->get_entities(domain) );
  
  for (Tk::Db::Ids::iterator iter( entity_ids.begin() );
       iter != entity_ids.end();
       ++iter)
    {
      Gtk::TreeModel::iterator row( _store->append() );
      row->set_value(_columns.id, *iter);
    }
}

void
DomainSelector:: add_selected(const Gtk::TreeModel::iterator &iter, Tk::Db::Ids &ids)
{
  ids.push_back( iter->get_value(_columns.id) );
}

Tk::Db::Ids
DomainSelector:: get_selected()
{
  Glib::RefPtr<Gtk::TreeSelection> selection( get_selection() );
  
  if (selection->count_selected_rows() < 1)
    throw NoSelection();
  
  Tk::Db::Ids ids;
  Gtk::TreeSelection::SlotForeachIter slot( sigc::bind<Tk::Db::Ids &>(sigc::mem_fun(*this, &DomainSelector::add_selected), ids) );
  selection->selected_foreach_iter(slot);
  return ids;
}

void
DomainSelector:: cell_data(Gtk::CellRenderer *cell, const Gtk::TreeModel::iterator &iter)
{
  Tk::Db::Id entity_id( iter->get_value(_columns.id) );
  Tk::String rendering( render_entity(entity_id) );
  
  dynamic_cast<Gtk::CellRendererText *>(cell)->property_text() = rendering;
}
