/* -*- c++ -*-
 * TkResolver++ - Psychokinesis testing software
 *
 * Copyright (C) 2008 Robert Ham <rah@bash.sh>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#ifndef __TK_PARSE_ERROR_H__
#define __TK_PARSE_ERROR_H__

#include "libtkcommon/tkstring.h"

#include "libtkquery/tkquery-parser.h"

namespace Tk {
  namespace Query {
    
    typedef yy::parser::location_type Location;
	
    class ParseError : public std::runtime_error
      {
      protected:
	Location     _location;
	std::string  _message;
      public:
	ParseError(const Location &loc, const std::string &type, const std::string &msg);
	virtual ~ParseError() throw () {};
	const Location &get_location() const;
	const std::string &get_message() const;
	virtual std::string get_type() const = 0;
      };
    
    class SyntaxError : public ParseError
      {
      public:
	SyntaxError(const Location &loc, const std::string &msg);
	virtual std::string get_type() const;
      };
    
    class SemanticError : public ParseError
      {
      public:
	SemanticError(const Location &loc, const std::string &msg);
	virtual std::string get_type() const;
      };
    
  }; /* namespace Query */
}; /* namespace Tk */

#endif /* __TK_PARSE_ERROR_H__ */
    
